@@ -64,7 +64,7 @@ async def cb_onconnect(reader, writer, cfg, cfg_input, queues_list, stats, geoip
 
                 # handle the DATA frame
                 if ctrl == fstrm.FSTRM_DATA_FRAME:
-                    loop.create_task(dnstap_decoder.cb_ondnstap(dnstap_protobuf, payload, cfg, queues_list, stats, geoip_reader, cache))
+                    await dnstap_decoder.cb_ondnstap(dnstap_protobuf, payload, cfg, queues_list, stats, geoip_reader, cache)
                     
                 # handle the control frame READY
                 if ctrl == fstrm.FSTRM_CONTROL_READY:
@@ -86,7 +86,15 @@ async def cb_onconnect(reader, writer, cfg, cfg_input, queues_list, stats, geoip
                 # handle the control frame STOP
                 if ctrl == fstrm.FSTRM_CONTROL_STOP:
                     clogger.debug(f"Input handler: control stop received from {peername}")
-                    fstrm_handler.reset()     
+                    fstrm_handler.reset()
+                    
+                    # send finish control
+                    ctrl_finish = fstrm_handler.encode(ctrl=fstrm.FSTRM_CONTROL_FINISH)
+                    writer.write(ctrl_finish)
+                    await writer.drain()
+                    
+                    clogger.debug(f"Input handler: sending control finish to {peername}")
+                    
     except ConnectionError as e:
         clogger.error(f'Input handler: {peername} - %s' % e)
     except asyncio.CancelledError:
