@@ -4,7 +4,7 @@ import sys
 clogger = logging.getLogger("dnstap_receiver.console")
 tap_logger = logging.getLogger("dnstap_receiver.output.stdout")
 
-from dnstap_receiver import transform
+from dnstap_receiver.outputs import transform
 
 def checking_conf(cfg):
     """validate the config"""
