@@ -16,7 +16,9 @@ async def watcher(statistics):
         # refresh counters and compute qps every interval
         statistics.update_counters()
         statistics.compute_qps()
-    
+        statistics.compute_rps()
+        statistics.compute_pps()
+        
 class StatsStream:
     def __init__(self, name, stats):
         """constructor"""
@@ -28,6 +30,7 @@ class StatsStream:
         self.bufi = defaultdict(Counter)
 
         self.prev_qr = 0
+        self.prev_rp = 0
         
         self.cnts = Counter()
         self.cnts_rcode = Counter()
@@ -39,14 +42,14 @@ class StatsStream:
         
     def record(self, tap):
         """record only response dnstap message"""
-        qname = tap["qname"]; srcip = tap["source-ip"]; 
+        qname = tap["qname"]; srcip = tap["query-ip"]; 
         qr = tap["type"]; rcode = tap["rcode"]; rrtype = tap["rrtype"]
         
         # transform qname to lowercase ?
         if self.stats.cfg["qname-lowercase"]:
             qname = qname.lower()
 
-        # count number of hit and bytes for each source ip
+        # count number of hit and bytes for each query ip
         self.bufi[srcip]["hit"] += 1
         self.bufi[srcip]["length"] += tap["length"]
         self.cnts["clients"] = len(self.bufi)
@@ -85,18 +88,19 @@ class StatsStream:
             self.cnts_tlds["%s/%s" % (qr,tld_matched[-1])] += 1
         
         # latency
-        if tap["latency"] <= 0.001:
-            self.cnts_latency["%s/latency0_1" % qr ] += 1
-        if 0.001 < tap["latency"] <= 0.010 :
-            self.cnts_latency["%s/latency1_10" % qr ] += 1
-        if 0.010 < tap["latency"] <= 0.050 :
-            self.cnts_latency["%s/latency10_50" % qr ] += 1
-        if 0.050 < tap["latency"] <= 0.100 :
-            self.cnts_latency["%s/latency50_100" % qr ] += 1
-        if 0.100 < tap["latency"] <= 1.000 :
-            self.cnts_latency["%s/latency100_1000" % qr ] += 1    
-        if tap["latency"] > 1.000 :
-            self.cnts_latency["%s/latency_slow" % qr ] += 1    
+        if isinstance(tap["latency"], float):
+            if tap["latency"] <= 0.001:
+                self.cnts_latency["%s/latency0_1" % qr ] += 1
+            if 0.001 < tap["latency"] <= 0.010 :
+                self.cnts_latency["%s/latency1_10" % qr ] += 1
+            if 0.010 < tap["latency"] <= 0.050 :
+                self.cnts_latency["%s/latency10_50" % qr ] += 1
+            if 0.050 < tap["latency"] <= 0.100 :
+                self.cnts_latency["%s/latency50_100" % qr ] += 1
+            if 0.100 < tap["latency"] <= 1.000 :
+                self.cnts_latency["%s/latency100_1000" % qr ] += 1    
+            if tap["latency"] > 1.000 :
+                self.cnts_latency["%s/latency_slow" % qr ] += 1    
             
     def reset(self):
         """reset the stream"""
@@ -113,7 +117,8 @@ class StatsStream:
         self.cnts_latency.clear()
         
         self.prev_qr = 0
-
+        self.prev_rp = 0
+        
     def compute_qps(self):
         """compute qps query/qps and response/qps"""
         cur_qr = self.cnts.get("query", 0)
@@ -124,6 +129,19 @@ class StatsStream:
         self.cnts["qps"]  = qps
         self.prev_qr = cur_qr
         
+    def compute_rps(self):
+        """compute response per second"""
+        cur_rp = self.cnts.get("response", 0)
+        if cur_rp == 0: return
+
+        rps = cur_rp - self.prev_rp
+        if rps < 0: rps = 0
+        self.cnts["rps"]  = rps
+        self.prev_rp = cur_rp
+        
+    def compute_pps(self):
+        self.cnts["pps"]  = self.cnts["qps"] + self.cnts["rps"]
+        
 class Statistics:
     def __init__(self, cfg):
         """constructor"""
@@ -144,6 +162,8 @@ class Statistics:
         self.cnts_latency = Counter()
         
         self.global_qps = Counter()
+        self.global_rps = Counter()
+        self.global_pps = Counter()
         
     def record(self, tap):
         """record dnstap message"""
@@ -190,7 +210,9 @@ class Statistics:
         self.cnts_rcode.clear()
         self.cnts_rrtype.clear()
         self.global_qps.clear()
-
+        self.global_rps.clear()
+        self.global_pps.clear()
+        
         self.cnts_tlds.clear()
         self.cnts_latency.clear()
         
@@ -219,6 +241,25 @@ class Statistics:
         
         self.cnts["qps"] = self.global_qps["qps"]
       
+    def compute_rps(self):
+        """create some global counters"""
+        self.global_rps.clear()
+        
+        for s in self.get_streams():
+            s.compute_rps()
+            self.global_rps.update({"rps": s.cnts["rps"]})
+        
+        self.cnts["rps"] = self.global_rps["rps"]
+        
+    def compute_pps(self):
+        self.global_pps.clear()
+        
+        for s in self.get_streams():
+            s.compute_pps()
+            self.global_pps.update({"pps": s.cnts["qps"] + s.cnts["rps"]})
+        
+        self.cnts["pps"] = self.global_pps["pps"]
+        
     def get_counters(self, stream=None, filters=[]):
         """return all counters"""
         # get computed counters according to the stream
